@@ -28,7 +28,7 @@ except ImportError: # pragma: no cover
     from urllib import urlencode as urlencode
 
 # External dependencies
-import better_exceptions as _better_exceptions
+# import better_exceptions as _better_exceptions
 import requests as _requests
 from yaml import load as _load_yaml
 try:
